@@ -231,68 +231,91 @@ namespace dmr {
     static void* GLAPIENTRY glMPGetNativeDisplay(const char* name) {
         qWarning() << __func__ << name;
         if (!strcmp(name, "x11") || !strcmp(name, "X11")) {
+            qDebug() << "DEBUG: X11 display detected.";
             return static_cast<void*>(QX11Info::display());
         }
+        qDebug() << "DEBUG: Exiting glMPGetNativeDisplay. No native display found or handled.";
         return nullptr;
     }
 
     static void* EGLAPIENTRY glMPGetNativeDisplay_EGL(const char* name) {
         qWarning() << __func__ << name;
+        qDebug() << "DEBUG: Entering glMPGetNativeDisplay_EGL. Name:" << name;
         //QPlatformNativeInterface* native = QGuiApplication::platformNativeInterface();
         //struct wl_display * wl_dpy = (struct wl_display*) (native->nativeResourceForWindow("display",NULL));
         if (!strcmp(name, "wayland")) {
+            qDebug() << "DEBUG: Wayland display detected.";
             //return (void*)wl_dpy;
             return nullptr;
         }
+        qDebug() << "DEBUG: Exiting glMPGetNativeDisplay_EGL. No Wayland display found or handled.";
         return nullptr;
     }
 
     static void *get_proc_address(void *pCtx, const char *pName) {
+        qDebug() << "DEBUG: Entering get_proc_address. Context:" << pCtx << ", Name:" << pName;
         Q_UNUSED(pCtx);
         QOpenGLContext *pGLCtx = QOpenGLContext::currentContext();
-        if (!pGLCtx)
+        if (!pGLCtx) {
+            qWarning() << "WARNING: OpenGL context is null, cannot get proc address.";
             return nullptr;
+        }
 
         if (!strcmp(pName, "glMPGetNativeDisplay")) {
             if(utils::check_wayland_env()){
+                qDebug() << "DEBUG: Resolved glMPGetNativeDisplay to EGL version for Wayland.";
                 return (void*)glMPGetNativeDisplay_EGL;
             }else{
+                qDebug() << "DEBUG: Resolved glMPGetNativeDisplay to X11 version for non-Wayland.";
                 return (void*)glMPGetNativeDisplay;
             }
         }
+        qDebug() << "DEBUG: Exiting get_proc_address. Resolved address for:" << pName;
         return reinterpret_cast<void*>(pGLCtx->getProcAddress(QByteArray(pName)));
     }
 
     static void gl_update_callback(void *pCtx)
     {
+        qDebug() << "DEBUG: Entering gl_update_callback.";
         MpvGLWidget *pWid = static_cast<MpvGLWidget*>(pCtx);
         QMetaObject::invokeMethod(pWid, "onNewFrame");
+        qDebug() << "DEBUG: Exiting gl_update_callback.";
     }
 
     //cppcheck 被QMetaObject::invokeMethod使用
     void MpvGLWidget::onNewFrame()
     {
+        qDebug() << "DEBUG: Entering onNewFrame.";
         if (window()->isMinimized()) {
+            qDebug() << "DEBUG: Window is minimized. Performing minimal update.";
             makeCurrent();
             paintGL();
             context()->swapBuffers(context()->surface());
             doneCurrent();
         } else {
+            qDebug() << "DEBUG: Window is not minimized. Performing full render context update.";
             m_renderContextUpdate(m_pRenderCtx);
             update();
         }
+        qDebug() << "DEBUG: Exiting onNewFrame.";
     }
 
     void MpvGLWidget::onFrameSwapped()
     {
+        qDebug() << "DEBUG: Entering onFrameSwapped.";
         //qInfo() << "frame swapped";
 
-        if(!m_context_report) return;
+        if(!m_context_report) {
+            qDebug() << "DEBUG: m_context_report is null. Exiting onFrameSwapped.";
+            return;
+        }
         m_context_report(m_pRenderCtx);
+        qDebug() << "DEBUG: Exiting onFrameSwapped.";
     }
 
     MpvGLWidget::MpvGLWidget(QWidget *parent, MpvHandle h)
         :QOpenGLWidget(parent), m_handle(h) {
+        qDebug() << "DEBUG: Entering MpvGLWidget constructor.";
 
         initMember();
 
@@ -302,63 +325,91 @@ namespace dmr {
 
         connect(this, &QOpenGLWidget::frameSwapped, 
                 this, &MpvGLWidget::onFrameSwapped, Qt::DirectConnection);
+        qDebug() << "DEBUG: Exiting MpvGLWidget constructor.";
     }
 
     MpvGLWidget::~MpvGLWidget() 
     {
+        qDebug() << "DEBUG: Entering MpvGLWidget destructor.";
         makeCurrent();
         if (m_pDarkTex) {
+            qDebug() << "DEBUG: Destroying dark texture.";
             m_pDarkTex->destroy();
             delete m_pDarkTex;
+            m_pDarkTex = nullptr;
         }
         if (m_pLightTex) {
+            qDebug() << "DEBUG: Destroying light texture.";
             m_pLightTex->destroy();
             delete m_pLightTex;
+            m_pLightTex = nullptr;
         }
 
         for (auto mask: m_pCornerMasks) {
-            if (mask) mask->destroy();
+            if (mask) {
+                qDebug() << "DEBUG: Destroying corner mask.";
+                mask->destroy();
+            }
         }
 
         m_vbo.destroy();
+        qDebug() << "DEBUG: VBO destroyed.";
 
         for (int i = 0; i < 4; i++) {
             m_vboCorners[i].destroy();
+            qDebug() << "DEBUG: Destroying VBO corner at index:" << i;
 
             ///指针数组m_pCornerMasks在mpv_glwidget.cpp 476行申请内存后未释放///
             delete m_pCornerMasks[i];
             m_pCornerMasks[i] = nullptr;
+            qDebug() << "DEBUG: Deleted corner mask pointer at index:" << i;
         }
 
         m_vao.destroy();
+        qDebug() << "DEBUG: VAO destroyed.";
         m_vaoBlend.destroy();
+        qDebug() << "DEBUG: VAO blend destroyed.";
         m_vaoCorner.destroy();
+        qDebug() << "DEBUG: VAO corner destroyed.";
 
         delete m_pGlProgBlend;
         m_pGlProgBlend = nullptr;
+        qDebug() << "DEBUG: GL program blend deleted.";
 
         delete m_pGlProgBlendCorners;
         m_pGlProgBlendCorners = nullptr;;
+        qDebug() << "DEBUG: GL program blend corners deleted.";
 
         delete m_pGlProg;
         m_pGlProg = nullptr;
+        qDebug() << "DEBUG: GL program deleted.";
 
         delete m_pGlProgCorner;
         m_pGlProgCorner = nullptr;
+        qDebug() << "DEBUG: GL program corner deleted.";
 
-        if (m_pFbo) delete m_pFbo;
+        if (m_pFbo) {
+            qDebug() << "DEBUG: Deleting FBO.";
+            delete m_pFbo;
+            m_pFbo = nullptr;
+        }
         //add by heyi
-        if (m_pRenderCtx) m_callback(m_pRenderCtx, nullptr, nullptr);
+        if (m_pRenderCtx) {
+            qDebug() << "DEBUG: Calling render context callback before free.";
+            m_callback(m_pRenderCtx, nullptr, nullptr);
+        }
         // Until this call is done, we need to make sure the player remains
         // alive. This is done implicitly with the mpv::qt::Handle instance
         // in this class.
         m_renderContex(m_pRenderCtx);
         //mpv_render_context_free(m_pRenderCtx);
         doneCurrent();
+        qDebug() << "DEBUG: Exiting MpvGLWidget destructor.";
     }
 
     void MpvGLWidget::setupBlendPipe()
     {
+        qDebug() << "DEBUG: Entering setupBlendPipe.";
         updateMovieFbo();
 
         m_vaoBlend.create();
@@ -368,8 +419,10 @@ namespace dmr {
         m_pGlProgBlend = new QOpenGLShaderProgram();
         m_pGlProgBlend->addShaderFromSourceCode(QOpenGLShader::Vertex, vs_blend);
         if(utils::check_wayland_env()){
+            qDebug() << "DEBUG: Setting up blend pipe for Wayland environment (fs_blend_wayland).";
             m_pGlProgBlend->addShaderFromSourceCode(QOpenGLShader::Fragment, fs_blend_wayland);
         }else {
+            qDebug() << "DEBUG: Setting up blend pipe for non-Wayland environment (fs_blend).";
             m_pGlProgBlend->addShaderFromSourceCode(QOpenGLShader::Fragment, fs_blend);
         }
 
@@ -388,38 +441,48 @@ namespace dmr {
         m_pGlProgBlend->setUniformValue("movie", 0);
         m_pGlProgBlend->release();
         m_vaoBlend.release();
+        qDebug() << "DEBUG: Blend shader program released and VAO/VBO blend released.";
 
         m_pGlProgBlendCorners = new QOpenGLShaderProgram();
         m_pGlProgBlendCorners->addShaderFromSourceCode(QOpenGLShader::Vertex, vs_blend_corner);
         if(utils::check_wayland_env()){
+            qDebug() << "DEBUG: Setting up blend pipe corners for Wayland environment (fs_blend_corner_wayland).";
             m_pGlProgBlendCorners->addShaderFromSourceCode(QOpenGLShader::Fragment, fs_blend_corner_wayland);
         }else{
+            qDebug() << "DEBUG: Setting up blend pipe corners for non-Wayland environment (fs_blend_corner).";
             m_pGlProgBlendCorners->addShaderFromSourceCode(QOpenGLShader::Fragment, fs_blend_corner);
         }
 
         if (!m_pGlProgBlendCorners->link()) {
             qInfo() << "link failed";
         }
+        qDebug() << "DEBUG: Exiting setupBlendPipe.";
     }
 
     void MpvGLWidget::setupIdlePipe()
     {
+        qDebug() << "DEBUG: Entering setupIdlePipe.";
         m_vao.create();
         m_vao.bind();
+        qDebug() << "DEBUG: VAO created and bound for idle pipe.";
 
         m_pDarkTex = new QOpenGLTexture(m_imgBgDark, QOpenGLTexture::DontGenerateMipMaps);
         m_pDarkTex->setMinificationFilter(QOpenGLTexture::Linear);
         m_pLightTex = new QOpenGLTexture(m_imgBgLight, QOpenGLTexture::DontGenerateMipMaps);
         m_pLightTex->setMinificationFilter(QOpenGLTexture::Linear);
+        qDebug() << "DEBUG: Dark and light splash textures created.";
 
         updateVbo();
         m_vbo.bind();
+        qDebug() << "DEBUG: VBO updated and bound for idle pipe.";
 
         m_pGlProg = new QOpenGLShaderProgram();
         m_pGlProg->addShaderFromSourceCode(QOpenGLShader::Vertex, vs_code);
         if(utils::check_wayland_env()){
+            qDebug() << "DEBUG: Setting up idle pipe for Wayland environment (fs_code_wayland).";
             m_pGlProg->addShaderFromSourceCode(QOpenGLShader::Fragment, fs_code_wayland);
         }else{
+            qDebug() << "DEBUG: Setting up idle pipe for non-Wayland environment (fs_code).";
             m_pGlProg->addShaderFromSourceCode(QOpenGLShader::Fragment, fs_code);
         }
 
@@ -437,20 +500,26 @@ namespace dmr {
         m_pGlProg->setUniformValue("sampler", 0);
         m_pGlProg->release();
         m_vao.release();
+        qDebug() << "DEBUG: Idle shader program released and VAO/VBO released.";
 
         {
+            qDebug() << "DEBUG: Entering idle pipe corner setup block.";
             m_vaoCorner.create();
             m_vaoCorner.bind();
+            qDebug() << "DEBUG: VAO created and bound for idle pipe corners.";
 
             // setting up corners
             updateVboCorners();
             updateCornerMasks();
+            qDebug() << "DEBUG: VBO corners and corner masks updated.";
 
             m_pGlProgCorner = new QOpenGLShaderProgram();
             m_pGlProgCorner->addShaderFromSourceCode(QOpenGLShader::Vertex, vs_code);
             if(utils::check_wayland_env()){
+                qDebug() << "DEBUG: Setting up idle pipe corners for Wayland environment (fs_corner_code_wayland).";
                 m_pGlProgCorner->addShaderFromSourceCode(QOpenGLShader::Fragment, fs_corner_code_wayland);
             }else{
+                qDebug() << "DEBUG: Setting up idle pipe corners for non-Wayland environment (fs_corner_code).";
                 m_pGlProgCorner->addShaderFromSourceCode(QOpenGLShader::Fragment, fs_corner_code);
             }
 
@@ -458,57 +527,76 @@ namespace dmr {
                 qInfo() << "link failed";
             }
             m_vaoCorner.release();
+            qDebug() << "DEBUG: Idle corner shader program released and VAO released.";
         }
+        qDebug() << "DEBUG: Exiting setupIdlePipe.";
     }
 
     void MpvGLWidget::prepareSplashImages()
     {
+        qDebug() << "DEBUG: Entering prepareSplashImages.";
         QPixmap pixmap;
         QImage img=utils::LoadHiDPIImage(":/resources/icons/dark/init-splash-bac.svg");
         pixmap=pixmap.fromImage(img);
+        qDebug() << "DEBUG: Loaded dark splash background image.";
 
         QPixmap pixmap2;
         QImage img1=QIcon::fromTheme("deepin-movie").pixmap(130, 130).toImage();
         pixmap2=pixmap2.fromImage(img1);
+        qDebug() << "DEBUG: Loaded deepin-movie icon for splash.";
 
         QPainter painter(&pixmap);
         painter.drawPixmap(98,127,pixmap2);
         m_imgBgDark=pixmap.toImage();
         m_imgBgDark.setDevicePixelRatio(qApp->devicePixelRatio());
+        qDebug() << "DEBUG: Dark splash image prepared.";
 
         QPixmap pixmap3;
         QImage image(pixmap.size(),QImage::Format_Alpha8);
         image.fill(QColor(0, 0, 0, 0));
         image.setDevicePixelRatio(qApp->devicePixelRatio());
         pixmap3=pixmap3.fromImage(image);
+        qDebug() << "DEBUG: Created alpha channel image for light splash.";
 
         QPixmap pixmap4;
         QImage img2=QIcon::fromTheme("deepin-movie").pixmap(130, 130).toImage();
         pixmap4=pixmap4.fromImage(img2);
+        qDebug() << "DEBUG: Loaded deepin-movie icon for light splash.";
 
         QPainter painter1(&pixmap3);
         painter1.drawPixmap(98,127,pixmap4);
         m_imgBgLight = pixmap3.toImage();
         m_imgBgLight.setDevicePixelRatio(qApp->devicePixelRatio());
+        qDebug() << "DEBUG: Light splash image prepared.";
     }
 
     //cppcheck误报
     void MpvGLWidget::initializeGL()
     {
+        qInfo() << "Initializing OpenGL context";
         QOpenGLFunctions *pGLFunction = QOpenGLContext::currentContext()->functions();
+        if (!pGLFunction) {
+            qCritical() << "CRITICAL: Failed to get OpenGL functions in initializeGL.";
+            return;
+        }
         float a = static_cast<float>(16.0 / 255.0);
 
         if (DGuiApplicationHelper::LightType == DGuiApplicationHelper::instance()->themeType()){
             a = static_cast<float>(252.0 / 255.0);
+            qDebug() << "Using light theme color";
         }
         if(parent()->property("color").isValid()) {
+            qDebug() << "DEBUG: Parent color property is valid.";
             QColor clr = parent()->property("color").value<QColor>();
             pGLFunction->glClearColor(clr.red()/255.f, clr.green()/255.f, clr.blue()/255.f, 1.0);
         } else {
+            qDebug() << "DEBUG: Parent color property is invalid, using default clear color.";
             pGLFunction->glClearColor(a, a, a, 1.0);
         }
+        qDebug() << "DEBUG: OpenGL clear color set.";
 
         prepareSplashImages();
+        qDebug() << "Setting up OpenGL pipelines";
         setupIdlePipe();
         setupBlendPipe();
 
@@ -517,14 +605,18 @@ namespace dmr {
         connect(window()->windowHandle(), &QWindow::windowStateChanged, [=]() {
             QWidget* pTopWid = this->topLevelWidget();
             bool rounded = !pTopWid->isFullScreen() && !pTopWid->isMaximized();
+            qDebug() << "Window state changed - rounded corners:" << rounded;
             // 全屏和最大化下不裁剪圆角
             m_bDoRoundedClipping = rounded;
 
             //wayland
             if(utils::check_wayland_env()) {
+                qDebug() << "DEBUG: Wayland environment detected - forcing rounded corners.";
                 rounded = true;
+                qDebug() << "Wayland environment detected - forcing rounded corners";
             }
             toggleRoundedClip(rounded);
+            qDebug() << "DEBUG: Rounded clip toggled.";
         });
 #endif
 #endif
@@ -534,45 +626,48 @@ namespace dmr {
 #else
         mpv_opengl_init_params gl_init_params = { get_proc_address, nullptr };
 #endif
-        //int adv_control = 1;
+        qInfo() << "Initializing MPV OpenGL render context";
         mpv_render_param params[] = {
             {MPV_RENDER_PARAM_API_TYPE, const_cast<char*>(MPV_RENDER_API_TYPE_OPENGL)},
             {MPV_RENDER_PARAM_OPENGL_INIT_PARAMS, &gl_init_params},
-
-            /*
-                 *    which saves a copy per video frame ("vd-lavc-dr" option
-                 *    needs to be enabled, and the rendering backend as well as the
-                 *    underlying GPU API/driver needs to have support for it).
-                 **/
-            //{MPV_RENDER_PARAM_ADVANCED_CONTROL, &adv_control},
             {MPV_RENDER_PARAM_X11_DISPLAY, reinterpret_cast<void*>(QX11Info::display())},
             {MPV_RENDER_PARAM_INVALID, nullptr}
         };
 
         if(utils::check_wayland_env()){
-            //QPlatformNativeInterface* native = QGuiApplication::platformNativeInterface();
-            //struct wl_display * wl_dpy = (struct wl_display*) (native->nativeResourceForWindow("display",NULL));
+            qInfo() << "Configuring MPV for Wayland environment";
             params[2] = {MPV_RENDER_PARAM_WL_DISPLAY, nullptr};
         }
 
         //add by heyi
-        if(!m_renderCreat) return;
+        if(!m_renderCreat) {
+            qCritical() << "MPV render context creation function not found";
+            return;
+        }
         if (m_renderCreat(&m_pRenderCtx, m_handle, params) < 0) {
+            qCritical() << "CRITICAL: Cannot initialize mpv gl context.";
             std::runtime_error("can not init mpv gl");
         }
+        qInfo() << "MPV OpenGL render context initialized successfully";
 
         m_callback(m_pRenderCtx, gl_update_callback,
                    reinterpret_cast<void*>(this));
+        qDebug() << "DEBUG: Exiting initializeGL.";
     }
 
     void MpvGLWidget::updateMovieFbo()
     {
-        if (!m_bUseCustomFBO) return;
+        if (!m_bUseCustomFBO) {
+            qDebug() << "Custom FBO not enabled, skipping update";
+            return;
+        }
 
         auto desiredSize = size() * qApp->devicePixelRatio();
+        qDebug() << "Updating movie FBO with size:" << desiredSize;
 
         if (m_pFbo) {
             if (m_pFbo->size() == desiredSize) {
+                qDebug() << "FBO size unchanged, skipping recreation";
                 return;
             }
             m_pFbo->release();
@@ -587,14 +682,19 @@ namespace dmr {
         m_pFbo = new QOpenGLFramebufferObject(desiredSize, format);
         // 检查 FBO 是否创建成功
         if (!m_pFbo || !m_pFbo->isValid()) {
-            qWarning() << "Failed to create FBO with size:" << desiredSize;
+            qCritical() << "Failed to create FBO with size:" << desiredSize;
             return;
         }
+        qDebug() << "FBO created successfully";
     }
 
     void MpvGLWidget::updateCornerMasks()
     {
-        if (!utils::check_wayland_env() && !m_bUseCustomFBO) return;
+        qDebug() << "updateCornerMasks";
+        if (!utils::check_wayland_env() && !m_bUseCustomFBO) {
+            qDebug() << "!utils::check_wayland_env() && !m_bUseCustomFBO";
+            return;
+        }
 
         for (int i = 0; i < 4; i++) {
             QSize sz(RADIUS, RADIUS);
@@ -647,11 +747,14 @@ namespace dmr {
                 m_pCornerMasks[i]->setWrapMode(QOpenGLTexture::ClampToEdge);
             }
         }
+        qDebug() << "updateCornerMasks end";
     }
 
     void MpvGLWidget::updateVboBlend()
     {
+        qDebug() << "updateVboBlend";
         if (!m_vboBlend.isCreated()) {
+            qDebug() << "m_vboBlend.create()";
             m_vboBlend.create();
         }
 
@@ -678,10 +781,12 @@ namespace dmr {
         m_vboBlend.bind();
         m_vboBlend.allocate(vdata, sizeof(vdata));
         m_vboBlend.release();
+        qDebug() << "updateVboBlend end";
     }
 
     void MpvGLWidget::updateVboCorners()
     {
+        qDebug() << "updateVboCorners";
         auto vp = rect().size();
         auto tex_sz = QSize(RADIUS, RADIUS);
         auto r = QRect(0, 0, vp.width(), vp.height());
@@ -695,6 +800,7 @@ namespace dmr {
 
         for (int i = 0; i < 4; i++) {
             if (!m_vboCorners[i].isCreated()) {
+                qDebug() << "m_vboCorners[i].create()";
                 m_vboCorners[i].create();
             }
 
@@ -730,11 +836,14 @@ namespace dmr {
             m_vboCorners[i].allocate(vdata, sizeof(vdata));
             m_vboCorners[i].release();
         }
+        qDebug() << "updateVboCorners end";
     }
 
     void MpvGLWidget::updateVbo()
     {
+        qDebug() << "updateVbo";
         if (!m_vbo.isCreated()) {
+            qDebug() << "m_vbo.create()";
             m_vbo.create();
         }
         //HACK: we assume if any of width or height is 380, then we are in mini mode
@@ -769,32 +878,38 @@ namespace dmr {
         m_vbo.bind();
         m_vbo.allocate(vdata, sizeof(vdata));
         m_vbo.release();
+        qDebug() << "updateVbo end";
     }
 
     void MpvGLWidget::resizeGL(int nWidth, int nHeight)
     {
-
+        qDebug() << "resizeGL";
         updateMovieFbo();
         updateVbo();
         if (m_bUseCustomFBO){
+            qDebug() << "updateVboCorners";
             updateVboCorners();
         }
         qInfo() << "GL resize" << nWidth << nHeight;
         QOpenGLWidget::resizeGL(nWidth, nHeight);
+        qDebug() << "resizeGL end";
     }
 
     void MpvGLWidget::toggleRoundedClip(bool bFalse)
     {
+        qDebug() << "toggleRoundedClip";
         // 设置圆角时使用自定的FBO，但在全屏和最大化时，通过
         // m_bDoRoundedClipping 设置是否实际应用圆角
         m_bUseCustomFBO = bFalse;
         makeCurrent();
         updateMovieFbo();
         update();
+        qDebug() << "toggleRoundedClip end";
     }
 
     void MpvGLWidget::initMember()
     {
+        qDebug() << "initMember";
         m_pRenderCtx = nullptr;
 
         m_bPlaying = false;
@@ -821,6 +936,7 @@ namespace dmr {
         m_renderContexRender = nullptr;
         m_renderContextUpdate = nullptr;
         m_bRawFormat = false;
+        qDebug() << "initMember end";
     }
 
     /*not used yet*/
@@ -831,25 +947,27 @@ namespace dmr {
 
     void MpvGLWidget::paintGL() 
     {
+        qDebug() << "paintGL";
         QOpenGLFunctions *pGLFunction = QOpenGLContext::currentContext()->functions();
-            if (!pGLFunction) {
-        qWarning() << "Failed to get OpenGL functions";
-        return;
-    }
+        if (!pGLFunction) {
+            qCritical() << "Failed to get OpenGL functions in paintGL";
+            return;
+        }
     
-    // 检查纹理是否有效
-    if (m_pLightTex && !m_pLightTex->isCreated()) {
-        qWarning() << "Light texture not created";
-        return;
-    }
+        // 检查纹理是否有效
+        if (m_pLightTex && !m_pLightTex->isCreated()) {
+            qWarning() << "Light texture not created in paintGL";
+            return;
+        }
         
         if (m_bPlaying) {
-
+            qDebug() << "Rendering video frame";
             qreal dpr = qApp->devicePixelRatio();
             QSize scaled = size() * dpr;
             int nFlip = 1;
 
             if (!m_bUseCustomFBO) {
+                qDebug() << "Using default framebuffer for rendering";
                 mpv_opengl_fbo fbo {
                     static_cast<int>(defaultFramebufferObject()), scaled.width(), scaled.height(), 0
                 };
@@ -862,9 +980,7 @@ namespace dmr {
 
                 m_renderContexRender(m_pRenderCtx, params);
             } else {
-                //pGLFunction->glEnable(GL_BLEND);
-                //pGLFunction->glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
-
+                qDebug() << "Using custom FBO for rendering";
                 m_pFbo->bind();
 
                 mpv_opengl_fbo fbo {
@@ -974,6 +1090,7 @@ namespace dmr {
             }
 #endif
         } else {
+            qDebug() << "Rendering idle state";
             pGLFunction->glEnable(GL_BLEND);
             pGLFunction->glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
             QColor color = QColor(37, 37, 37, 255);
@@ -1092,7 +1209,7 @@ namespace dmr {
 
     void MpvGLWidget::initMpvFuns()
     {
-        qInfo() << "MpvGLWidget开始initMpvFuns";
+        qInfo() << "Initializing MPV functions";
         QLibrary mpvLibrary(SysUtils::libPath("libmpv.so"));
         m_callback = reinterpret_cast<mpv_render_contextSet_update_callback>(mpvLibrary.resolve("mpv_render_context_set_update_callback"));
         m_context_report = reinterpret_cast<mpv_render_contextReport_swap>(mpvLibrary.resolve("mpv_render_context_report_swap"));
